use log::info;
use rouille::Response;

use crate::utils::{flash::FlashResponse, sbot::systemctl_sbot_cmd};

// ROUTE: /settings/scuttlebutt/start

/// Attempt to start the go-sbot.service process.
/// Redirect to the Scuttlebutt settings menu and communicate the outcome of
/// the attempt via a flash message.
pub fn start_sbot() -> Response {
    info!("Starting go-sbot.service");
    let (flash_name, flash_msg) = match systemctl_sbot_cmd("start") {
        Ok(_) => (
            "success".to_string(),
            "Sbot process has been started".to_string(),
        ),
        Err(_) => (
            "error".to_string(),
            "Failed to start the sbot process".to_string(),
        ),
    };

    // redirect to the scuttlebutt settings menu
    Response::redirect_303("/settings/scuttlebutt").add_flash(flash_name, flash_msg)
}
